export(wrap_glmnet)
export(wrap_lightgbm)
export(wrap_ranger)
export(wrap_svm)
export(wrap_caret)
S3method(predict, wrap_glmnet)
S3method(predict, wrap_lightgbm)
S3method(predict, wrap_ranger)
S3method(predict, wrap_svm)
S3method(predict, wrap_caret)
importFrom("stats", "predict")
importFrom("e1071", "svm")
importFrom("glmnet", "glmnet")
importFrom("lightgbm", "lightgbm")
importFrom("ranger", "ranger")
